==> core_models-0.1.0.gem: app/controllers/core_models/misc/tax_classes_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Misc::TaxClassesController < CoreModelsController
    # GET /misc/tax_classes
    # GET /misc/tax_classes.json
    def index
      @misc_tax_classes = Misc::TaxClass.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @misc_tax_classes }
      end
    end

    # GET /misc/tax_classes/1
    # GET /misc/tax_classes/1.json
    def show
      @misc_tax_class = Misc::TaxClass.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @misc_tax_class }
      end
    end

    # GET /misc/tax_classes/new
    # GET /misc/tax_classes/new.json
    def new
      @misc_tax_class = Misc::TaxClass.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @misc_tax_class }
      end
    end

    # GET /misc/tax_classes/1/edit
    def edit
      @misc_tax_class = Misc::TaxClass.find(params[:id])
    end

    # POST /misc/tax_classes
    # POST /misc/tax_classes.json
    def create
      @misc_tax_class = Misc::TaxClass.new(params[:misc_tax_class])

      respond_to do |format|
        if @misc_tax_class.save
          format.html { redirect_to @misc_tax_class, :notice => 'Tax class was successfully created.' }
          format.json { render :json => @misc_tax_class, :status => :created, :location => @misc_tax_class }
        else
          format.html { render :action => "new" }
          format.json { render :json => @misc_tax_class.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /misc/tax_classes/1
    # PUT /misc/tax_classes/1.json
    def update
      @misc_tax_class = Misc::TaxClass.find(params[:id])

      respond_to do |format|
        if @misc_tax_class.update_attributes(params[:misc_tax_class])
          format.html { redirect_to @misc_tax_class, :notice => 'Tax class was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @misc_tax_class.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /misc/tax_classes/1
    # DELETE /misc/tax_classes/1.json
    def destroy
      @misc_tax_class = Misc::TaxClass.find(params[:id])
      @misc_tax_class.destroy

      respond_to do |format|
        format.html { redirect_to misc_tax_classes_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/misc/tax_classes_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Misc::TaxClassesController < CoreModelsController
    # GET /misc/tax_classes
    # GET /misc/tax_classes.json
    def index
      @misc_tax_classes = Misc::TaxClass.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @misc_tax_classes }
      end
    end

    # GET /misc/tax_classes/1
    # GET /misc/tax_classes/1.json
    def show
      @misc_tax_class = Misc::TaxClass.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @misc_tax_class }
      end
    end

    # GET /misc/tax_classes/new
    # GET /misc/tax_classes/new.json
    def new
      @misc_tax_class = Misc::TaxClass.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @misc_tax_class }
      end
    end

    # GET /misc/tax_classes/1/edit
    def edit
      @misc_tax_class = Misc::TaxClass.find(params[:id])
    end

    # POST /misc/tax_classes
    # POST /misc/tax_classes.json
    def create
      @misc_tax_class = Misc::TaxClass.new(params[:misc_tax_class])

      respond_to do |format|
        if @misc_tax_class.save
          format.html { redirect_to @misc_tax_class, :notice => 'Tax class was successfully created.' }
          format.json { render :json => @misc_tax_class, :status => :created, :location => @misc_tax_class }
        else
          format.html { render :action => "new" }
          format.json { render :json => @misc_tax_class.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /misc/tax_classes/1
    # PUT /misc/tax_classes/1.json
    def update
      @misc_tax_class = Misc::TaxClass.find(params[:id])

      respond_to do |format|
        if @misc_tax_class.update(params[:misc_tax_class])
          format.html { redirect_to @misc_tax_class, :notice => 'Tax class was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @misc_tax_class.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /misc/tax_classes/1
    # DELETE /misc/tax_classes/1.json
    def destroy
      @misc_tax_class = Misc::TaxClass.find(params[:id])
      @misc_tax_class.destroy

      respond_to do |format|
        format.html { redirect_to misc_tax_classes_url }
        format.json { head :no_content }
      end
    end
  end
end
